==> haskell-dav-1.3.4-224-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-5BALaCCni9XDawF3rrSFuR
key:                  DAV-1.3.4-5BALaCCni9XDawF3rrSFuR
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  5fc23a455d7594ab3d8f3bba3294d14e
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-8.10.3/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/DAV-1.3.4
hs-libraries:         HSDAV-1.3.4-5BALaCCni9XDawF3rrSFuR
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    case-insensitive-1.2.1.0-Awlxz7bDRim3eWRVduWPzP containers-0.6.2.1
    data-default-0.7.1.1-4D834HG4S3pBjO3a7I4Zox exceptions-0.10.4
    http-client-0.7.3-KrrsNb3aQaRLK5yFxY8Sve
    http-client-tls-0.3.5.3-1IbeFwf83trAY98bu9WpqQ
    http-types-0.12.3-7SXEKNW2VQSIfrnkRX6jGO
    lens-4.19.2-A7vbUVtWOp9LirlFFzJs9P mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-2X5KhLYYRPq6ROFyHEKN8Y
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM
    utf8-string-1.0.1.1-JbA4xmu2XMa1nQo1Lcnh9T
    xml-conduit-1.9.0.0-4lNrEJdOVvPI9Or2J724Om
    xml-hamlet-0.5.0.1-Cxkw9BaVEUK3D4ldT7Qji4

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.4-243-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-751PKMBCAv0E39ULAgw6J6
key:                  DAV-1.3.4-751PKMBCAv0E39ULAgw6J6
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  664561aab0f7f99f541c10ee496e2a9b
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-8.10.3/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/DAV-1.3.4
hs-libraries:         HSDAV-1.3.4-751PKMBCAv0E39ULAgw6J6
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    case-insensitive-1.2.1.0-L0gITQjreIr3hbLO2ORRC8 containers-0.6.2.1
    data-default-0.7.1.1-DlCqbdzfJ1T38tQdGVJmqu exceptions-0.10.4
    http-client-0.7.4-FkpQ2oEv3V8AD8q1HLj2qd
    http-client-tls-0.3.5.3-JA9nvkBJrPRLUXIB2etUtD
    http-types-0.12.3-HetwNy3mgGeDENuBKZCm39
    lens-4.19.2-GgOuycLtkOG4Jd2fARVvD6 mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-JI9ZhR9ey9m6XGYRNPETW0
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM
    utf8-string-1.0.2-CkwPGvXHIXdEOOrPn2UOUp
    xml-conduit-1.9.0.0-HJDGbryV6mxE28eLaYu3v1
    xml-hamlet-0.5.0.1-ESpWBSwwxdv8YGJWKCG0Jr

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
